package Bundle::PDF;


our $VERSION = '0.01';



1;
__END__

=head1 NAME

Bundle::PDF - A bundle to install PDF modules and dependencies

=head1 SYNOPSIS

  C<perl -MCPAN -e 'install Bundle::PDF'>

=head1 CONTENTS

PDF

Text::Roman

PDF::API2

Compress::Zlib

File::Copy

Getopt::Long

UNIVERSAL::isa

version

Error

Graphics::ColorNames

Image::Size

LWP::Simple

List::Util

PDF::Writer

XML::Twig

XML::Clean

HTML::Tidy

XML::Simple

Number::Format

XML::Parser

Pdf::FromHTML

PDF::Report

PDF::ReportWriter

PDF::Create

Test::More

IO::Scalar

PDF::Labels

PDF::Reuse

PDF::Reuse::Tutorial

PDF::Reuse::Barcode

CAM::PDF

Exporter

Autoloader

Text::PDF

Crypt::RC4

Digest::MD5

File::Temp

IO::All

IPC::Open2

GD

GD::Barcode

Pod::Parser

AppConfig

Parse::RecDescent

Class::MethodMaker

PDF::EasyPDF

PDF::Tk

PDF::Extract

PDF::Table

PDF::API2::Simple

PDF::FDF::Simple

PDF::Xtract


=head2 Description

PDF::CreateSimple was left out because of compilation problems. 
PDF::Template was left out because it requires the third-party
PDFLib-Lite.


=head1 SEE ALSO

For PDFLib-Lite. see www.pdflib.com

=head1 AUTHOR

Kevin W. Henwood, E<lt>khen1950fx@aol.com<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2006 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut
